.. :changelog:

History
========

0.0.9 (2017-06-05)
-------------------

* Cleaned up travis configuration for tox to improve testing

0.0.8 (2017-05-09)
-------------------

* Make it Compatible with Django 1.11

0.0.7 (2016-09-25)
-------------------

* Make Compatible with Django 1.10
* Minimum version is now Django 1.8. For earlier versions of Django use 0.0.6

0.0.6 (2016-08-05)
------------------

Fix for checkbox rendering and New error class for Non field errors in Foundation 6 

0.0.5 (2016-07-12)
---------------------

* First release on PyPI.
